@@ -15,15 +15,15 @@
 #
 ##############################################################################
 import colorlog
+
 logger = colorlog.getLogger(__name__)
 
 
-
-__all__ = ['BED']
+__all__ = ["BED"]
 
 
 class BED(object):
-    """a structure to read and manipulate BED files (12-column file) 
+    """a structure to read and manipulate BED files (12-column file)
 
     columns are defined as chromosome name, start and end, gene_name, score,
     strand, CDS start and end, blcok count, block sizes, block starts:
@@ -35,23 +35,24 @@ class BED(object):
 
     def _get_line(self, line):
         try:
-            if line.startswith('#') or  line.startswith('track') \
-                or line.startswith('browser'):
+            if line.startswith("#") or line.startswith("track") or line.startswith("browser"):
                 return {}
             else:
-                fields = line.rstrip('\r\n').split()
+                fields = line.rstrip("\r\n").split()
                 chrom_start = int(fields[1])
-                return {"chrom": fields[0],
-                        "start": chrom_start,
-                        "end": int(fields[2]),
-                        "gene_name": fields[3],
-                        "score": fields[4],
-                        "strand": fields[5],
-                        "cds_start": int(fields[6]),
-                        "cds_end": int(fields[7]),
-                        "block_count": int(fields[9]),
-                        "block_sizes": [int(x) for x in fields[10].strip(',').split(',')],
-                        "block_starts": [int(x)+chrom_start for x in fields[11].strip(",").split(",")]}
+                return {
+                    "chrom": fields[0],
+                    "start": chrom_start,
+                    "end": int(fields[2]),
+                    "gene_name": fields[3],
+                    "score": fields[4],
+                    "strand": fields[5],
+                    "cds_start": int(fields[6]),
+                    "cds_end": int(fields[7]),
+                    "block_count": int(fields[9]),
+                    "block_sizes": [int(x) for x in fields[10].strip(",").split(",")],
+                    "block_starts": [int(x) + chrom_start for x in fields[11].strip(",").split(",")],
+                }
         except Exception as err:
             print(err)
             print("Input bed must be 12-column] skipped line {}".format(line))
@@ -61,7 +62,8 @@ class BED(object):
         count = 0
         with open(self.filename, "r") as fin:
             for line in fin:
-                if line.startswith(('#', 'track', 'browser')): continue
+                if line.startswith(("#", "track", "browser")):
+                    continue
                 count += 1
         return count
 
@@ -82,35 +84,48 @@ class BED(object):
         exons = []
         with open(self.filename, "r") as fin:
             for line in fin:
-                if line.startswith('#'): continue
-                if line.startswith('track'): continue
-                if line.startswith('browser'): continue
-                fields = line.rstrip('\r\n').split()
-                assert len(fields) == 12 
+                if line.startswith("#"):
+                    continue
+                if line.startswith("track"):
+                    continue
+                if line.startswith("browser"):
+                    continue
+                fields = line.rstrip("\r\n").split()
+                assert len(fields) == 12
                 chrom_start = int(fields[1])
                 chrom_name = fields[0]
-                block_sizes =(int(x) for x in fields[10].strip(',').split(','))
-                block_starts =  (int(x)+chrom_start for x in fields[11].strip(",").split(","))
+                block_sizes = (int(x) for x in fields[10].strip(",").split(","))
+                block_starts = (int(x) + chrom_start for x in fields[11].strip(",").split(","))
                 for start, size in zip(block_starts, block_sizes):
-                    exons.append((chrom_name, start, start+size))
+                    exons.append((chrom_name, start, start + size))
         return exons
 
     def get_transcript_ranges(self):
         """Extract transcript from input BED file."""
         with open(self.filename, "r") as fin:
             for line in fin:
-                if line.startswith('#'): continue
-                if line.startswith('track'): continue
-                if line.startswith('browser'): continue
-                fields = line.rstrip('\r\n').split()
-                assert len(fields) == 12 
+                if line.startswith("#"):
+                    continue
+                if line.startswith("track"):
+                    continue
+                if line.startswith("browser"):
+                    continue
+                fields = line.rstrip("\r\n").split()
+                assert len(fields) == 12
                 chrom = fields[0]
                 chrom_start = int(fields[1])
                 chrom_end = int(fields[2])
                 strand = fields[5]
                 gene_name = fields[3]
-                yield([chrom, chrom_start, chrom_end, strand,
-                        "{}:{}:{}-{}".format(gene_name, chrom, chrom_start, chrom_end)])
+                yield (
+                    [
+                        chrom,
+                        chrom_start,
+                        chrom_end,
+                        strand,
+                        "{}:{}:{}-{}".format(gene_name, chrom, chrom_start, chrom_end),
+                    ]
+                )
 
     def get_CDS_exons(self):
         """Extract CDS from input BED file."""
@@ -121,47 +136,12 @@ class BED(object):
                 if row:
                     cds_start = row["cds_start"]
                     cds_end = row["cds_end"]
-                    for start, size in zip( row['block_starts'], row['block_sizes'] ):
-                        if (start + size) < cds_start: 
+                    for start, size in zip(row["block_starts"], row["block_sizes"]):
+                        if (start + size) < cds_start:
                             continue
-                        if start > cds_end: 
+                        if start > cds_end:
                             continue
-                        exon_start = max( start, cds_start )
-                        exon_end = min( start+size, cds_end )
-                        results.append([row['chrom'], exon_start, exon_end])
+                        exon_start = max(start, cds_start)
+                        exon_end = min(start + size, cds_end)
+                        results.append([row["chrom"], exon_start, exon_end])
         return results
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
